@@ -7,6 +7,7 @@
 #include <QApplication>
 #include <QProcess>
 #include <QThread>
+#include <QPointer>
 
 #ifdef QSYSTRAY
 #include <QSystemTrayIcon>
@@ -18,6 +19,7 @@
 #include <KAboutData>
 #include <KCMultiDialog>
 #include <KLocalizedString>
+#include <KColorSchemeManager>
 
 #include "interfaces/devicesmodel.h"
 #include "interfaces/dbusinterfaces.h"
@@ -40,12 +42,18 @@ int main(int argc, char** argv)
                      i18n("(C) 2016 Aleix Pol Gonzalez"));
     KAboutData::setApplicationData(about);
 
-    about.setProgramLogo(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.svg")));
+#ifdef Q_OS_WIN
+    KColorSchemeManager manager;
+    QApplication::setStyle(QStringLiteral("breeze"));
+    IndicatorHelper helper(QUrl::fromLocalFile(qApp->applicationDirPath()));
+#else
     IndicatorHelper helper;
+#endif
 
     helper.preInit();
 
     // Run Daemon initialization step
+    // When run from macOS app bundle, D-Bus call should be later than kdeconnectd and D-Bus daemon
     QProcess kdeconnectd;
     if (helper.daemonHook(kdeconnectd)) {
         return -1;
@@ -53,19 +61,29 @@ int main(int argc, char** argv)
 
     KDBusService dbusService(KDBusService::Unique);
 
+    // Trigger loading the KIconLoader plugin
+    about.setProgramLogo(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.svg")));
+
     DevicesModel model;
     model.setDisplayFilter(DevicesModel::Reachable | DevicesModel::Paired);
     QMenu* menu = new QMenu;
 
+    QPointer<KCMultiDialog> dialog;
+
     DaemonDbusInterface iface;
-    auto refreshMenu = [&iface, &model, &menu, &helper]() {
+
+    auto refreshMenu = [&iface, &model, &menu, &helper, &dialog]() {
         menu->clear();
         auto configure = menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure..."));
-        QObject::connect(configure, &QAction::triggered, configure, [](){
-            KCMultiDialog* dialog = new KCMultiDialog;
-            dialog->addModule(QStringLiteral("kcm_kdeconnect"));
-            dialog->setAttribute(Qt::WA_DeleteOnClose);
-            dialog->show();
+        QObject::connect(configure, &QAction::triggered, configure, [&dialog]() {
+            if (dialog == nullptr) {
+                dialog = new KCMultiDialog;
+                dialog->addModule(QStringLiteral("kcm_kdeconnect"));
+                dialog->setAttribute(Qt::WA_DeleteOnClose);
+                dialog->show();
+            } else {
+                dialog->activateWindow();
+            }
         });
         for (int i=0, count = model.rowCount(); i<count; ++i) {
             DeviceDbusInterface* device = model.getDevice(i);
@@ -102,12 +120,7 @@ int main(int argc, char** argv)
         });
 #elif defined Q_OS_WIN
 
-        menu->addAction(i18n("Quit"), [&helper](){
-            const QUrl indicatorUrl = QUrl::fromLocalFile(qApp->applicationDirPath());
-            helper.terminateProcess(processes::dbus_daemon, indicatorUrl);
-            helper.terminateProcess(processes::kdeconnect_daemon, indicatorUrl);
-            qApp->quit();
-        });
+        menu->addAction(QIcon::fromTheme(QStringLiteral("application-exit")), i18n("Quit"), [](){qApp->quit();});
 #endif
     };
 
@@ -126,6 +139,14 @@ int main(int argc, char** argv)
     QObject::connect(&model, &DevicesModel::rowsChanged, &model, [&systray, &model]() {
         systray.setToolTip(i18np("%1 device connected", "%1 devices connected", model.rowCount()));
     });
+    QObject::connect(&systray, &QSystemTrayIcon::activated, [&iface](QSystemTrayIcon::ActivationReason reason) {
+        if (reason == QSystemTrayIcon::Trigger) {
+            const QString kdeconnectAppExecutable = QStandardPaths::findExecutable(QStringLiteral("kdeconnect-app"), { QCoreApplication::applicationDirPath() });
+            if (!kdeconnectAppExecutable.isEmpty()) {
+                QProcess::startDetached(kdeconnectAppExecutable);
+            }
+        }
+    });
 
     systray.setContextMenu(menu);
 #else
