@@ -8,6 +8,8 @@
 
 #include <QCursor>
 #include <QDebug>
+#include <chrono>
+#include <thread>
 
 #include <Windows.h>
 
@@ -73,7 +75,7 @@ bool WindowsRemoteInput::handlePacket(const NetworkPacket& np)
     QString key = np.get<QString>(QStringLiteral("key"), QLatin1String(""));
     int specialKey = np.get<int>(QStringLiteral("specialKey"), 0);
 
-    if (isSingleClick || isDoubleClick || isMiddleClick || isRightClick || isSingleHold || isScroll || !key.isEmpty() || specialKey) {
+    if (isSingleClick || isDoubleClick || isMiddleClick || isRightClick || isSingleHold || isScroll || isSingleRelease || !key.isEmpty() || specialKey) {
 
 		INPUT input={0};
 		input.type = INPUT_MOUSE;
@@ -235,8 +237,12 @@ bool WindowsRemoteInput::handlePacket(const NetworkPacket& np)
         }
 
     } else { //Is a mouse move event
-        QPoint point = QCursor::pos();
-        QCursor::setPos(point.x() + (int)dx, point.y() + (int)dy);
+        POINT point;
+        if (GetCursorPos(&point)) {
+            SetCursorPos(point.x + (int)dx, point.y + (int)dy);
+            // wait for a microsecond here to allow Windows to interpolate
+            std::this_thread::sleep_for(std::chrono::microseconds(1));
+        }
     }
     return true;
 }
